@@ -3,7 +3,7 @@
 
 """Image manipulation."""
 
-# internal modules
+# First party
 import mpu
 
 
@@ -22,22 +22,15 @@ def get_meta(filepath):
     meta = {}
     try:
         from PIL import Image
+
         with Image.open(filepath) as img:
             width, height = img.size
-        meta['width'] = width
-        meta['height'] = height
-        meta['channels'] = len(img.mode)  # RGB, RGBA - does this always work?
-    except ImportError:
-        pass
-    try:
-        import scipy.ndimage
-        height, width, channels = scipy.ndimage.imread(filepath).shape
-        meta['width'] = width
-        meta['height'] = height
-        meta['channels'] = channels
+        meta["width"] = width
+        meta["height"] = height
+        meta["channels"] = len(img.mode)  # RGB, RGBA - does this always work?
     except ImportError:
         pass
 
     # Get times - creation, last edit, last open
-    meta['file'] = mpu.io.get_file_meta(filepath)
+    meta["file"] = mpu.io.get_file_meta(filepath)
     return meta
